==> angular2-modal-1.0.9.jar: META-INF/resources/webjars/angular2-modal/1.0.9/plugins/vex/presets/dropin-preset.d.ts <==
import { ResolvedReflectiveProvider } from '@angular/core';
import { DROP_IN_TYPE } from '../../../models/tokens';
import { FluentAssignMethod } from '../../../framework/fluent-assign';
import { Modal } from '../modal';
import { DialogPreset, DialogPresetBuilder } from './dialog-preset';
/**
 * Data definition
 */
export declare class DropInPreset extends DialogPreset {
    /**
     * the message to display on the modal.
     */
    message: string;
    /**
     * OK button caption.
     * Default: OK
     * Set to false ('', undefined, null, false) to remove button.
     */
    okBtn: string;
    /**
     * Cancel button caption.
     * Default: Cancel
     * Set to false ('', undefined, null, false) to remove button.
     */
    cancelBtn: string;
    /**
     * A placeholder for the input element.
     * Valid only for prompt modal.
     */
    placeholder: string;
    dropInType: DROP_IN_TYPE;
    showInput: boolean;
}
/**
 * A Preset representing all 3 drop ins (alert, prompt, confirm)
 */
export declare class DropInPresetBuilder extends DialogPresetBuilder<DropInPreset> {
    /**
     * the message to display on the modal.
     */
    message: FluentAssignMethod<string, this>;
    /**
     * The default Ok button caption.
     */
    okBtn: FluentAssignMethod<string, this>;
    /**
     * The default Cancel button caption.
     */
    cancelBtn: FluentAssignMethod<string, this>;
    /**
     * A placeholder for the input element.
     * Valid only for prompt modal.
     */
    placeholder: FluentAssignMethod<string, this>;
    constructor(modal: Modal, dropInType: DROP_IN_TYPE, defaultValues?: DropInPreset);
    $$beforeOpen(config: DropInPreset): ResolvedReflectiveProvider[];
}

==> angular2-modal-1.1.5.jar: META-INF/resources/webjars/angular2-modal/1.1.5/plugins/vex/presets/dropin-preset.d.ts <==
/**
 * angular2-modal - Angular2 Modal (dialog) window.
 * @version v1.1.1
 * @link https://github.com/shlomiassaf/angular2-modal
 * @license MIT
 */
import { ResolvedReflectiveProvider } from '@angular/core';
import { DROP_IN_TYPE, FluentAssignMethod } from 'angular2-modal';
import { Modal } from '../modal';
import { DialogPreset, DialogPresetBuilder } from './dialog-preset';
/**
 * Data definition
 */
export declare class DropInPreset extends DialogPreset {
    /**
     * the message to display on the modal.
     */
    message: string;
    /**
     * OK button caption.
     * Default: OK
     * Set to false ('', undefined, null, false) to remove button.
     */
    okBtn: string;
    /**
     * Cancel button caption.
     * Default: Cancel
     * Set to false ('', undefined, null, false) to remove button.
     */
    cancelBtn: string;
    /**
     * A placeholder for the input element.
     * Valid only for prompt modal.
     */
    placeholder: string;
    dropInType: DROP_IN_TYPE;
    showInput: boolean;
}
/**
 * A Preset representing all 3 drop ins (alert, prompt, confirm)
 */
export declare class DropInPresetBuilder extends DialogPresetBuilder<DropInPreset> {
    /**
     * the message to display on the modal.
     */
    message: FluentAssignMethod<string, this>;
    /**
     * The default Ok button caption.
     */
    okBtn: FluentAssignMethod<string, this>;
    /**
     * The default Cancel button caption.
     */
    cancelBtn: FluentAssignMethod<string, this>;
    /**
     * A placeholder for the input element.
     * Valid only for prompt modal.
     */
    placeholder: FluentAssignMethod<string, this>;
    constructor(modal: Modal, dropInType: DROP_IN_TYPE, defaultValues?: DropInPreset);
    $$beforeOpen(config: DropInPreset): ResolvedReflectiveProvider[];
}
